==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetEfectivityPlans.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE  PROCEDURE [dbo].[GetEfectivityPlans] (
@VCC                Varchar(50) = NULL,
@SearchCriteria     Varchar(50) = NULL,
@SearchExpression   Varchar(50) = NULL
)
AS
BEGIN
SET NOCOUNT ON

	--SELECCIONAMOS TODOS LOS PLANES AUTOMATICOS EXISTENTES PARA GENERAR  LA MUESTRA  A PARTIR DEL PLAN DE EVALUACION

    SELECT
			e.[ID]							'id',
			e.[Modality]					'modality',
			e.[DateFin]						'dateFin',
			e.CreatedDate					'createdDate',
			e.CreatedByUserId				'createdByUserId',
			e.LastModifiedDate				'lastModifiedDate',
			e.LastModifiedByUserId			'lastModifiedByUserId',
			e.Description					'description',
			e.IdEvaluationFormat            'idEvaluationFormat',
			e.Enabled						'enabled',
			e.Status						'status',
			e.Evaluation_Mode				'evaluation_mode',
			e.processId    				    'processId',
			ef.templateId    				'templateId',
			COUNT(a.IdInteraction)			'totalEvaluations',		
			COUNT(DISTINCT CASE a.[Completed] WHEN 1 THEN a.[IdInteraction] ELSE NULL END)					'completedEvaluations',
			(
				(
					CAST(
						COUNT(DISTINCT CASE a.[Completed] WHEN 1 THEN a.[IdInteraction] ELSE NULL END)
						+ 
						COUNT(DISTINCT CASE a.[Status] WHEN 0 THEN a.[IdInteraction] ELSE NULL END)
					 AS NUMERIC(6,2)) 
				)
				/
				CASE COUNT(DISTINCT a.[IdInteraction]) WHEN 0 THEN 1 ELSE COUNT(DISTINCT a.[IdInteraction]) END 
			) * 100																							'completedPercentage',
			e.[Percentage]					'percentage',
			e.[StatusDescription]			'statusDescription',
			e.[BatchStatus]					'batchStatus'		
		FROM EvaluationPlan e (NOLOCK)
		LEFT JOIN AuditorEvaluationPlan a (NOLOCK) 
			ON a.[Instance] = e.[Instance]
				AND a.[IdEvaluationPlan] = e.[ID]
		LEFT JOIN EvaluationFormat ef (NOLOCK)
			ON ef.[Instance] = e.[Instance]
				AND ef.[ID] = e.[IdEvaluationFormat]
        
		WHERE e.Instance = @VCC
			AND e.Evaluation_Mode IN ('A','X')
			AND e.Status = '7'			
		GROUP BY e.[ID],e.[Modality],e.[DateFin],e.CreatedDate,e.CreatedByUserId,
				 e.LastModifiedDate,e.LastModifiedByUserId,e.Description,e.IdEvaluationFormat,
				 e.Enabled, e.Status, e.Evaluation_Mode,e.processId,ef.templateId, 
				 e.Percentage, e.StatusDescription, e.[BatchStatus]	
		
		
		--SELECCIONAR PLANES DE EFECTIVIDAD GENERADOS PARA LA GRILLA DE ADMINISTRACION 

		;WITH Temp_EfectivityPlan AS (

		SELECT DISTINCT 
		[EfectivityPlanId],[EvaluationPlanId],[InteractionId],[EfectivityStatus] 
		FROM dbo.[EvaluationResultEfectivity] (NOLOCK)
		WHERE [VCC] = @VCC
		),
		Temp_EfectivityPlan_Result  AS (
		SELECT [EfectivityPlanId],[EvaluationPlanId],COUNT(InteractionId)  'total',
		COUNT(DISTINCT CASE WHEN [EfectivityStatus] = 'COMPLETED' THEN [InteractionId] ELSE NULL END)					'completedEvaluations',
		CAST(CAST(COUNT(DISTINCT CASE WHEN [EfectivityStatus] = 'COMPLETED' THEN [InteractionId] ELSE NULL END) AS DECIMAL(10,2))*100
		/
		CAST(COUNT(InteractionId) AS DECIMAL(10,2)) AS DECIMAL)															'completedPercentage'
		
        FROM Temp_EfectivityPlan EP1		

		WHERE  ISNULL(EfectivityPlanId, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
			
		
		GROUP BY  EfectivityPlanId,EvaluationPlanId
		)		

		SELECT DISTINCT 
		TER.[EfectivityPlanId] 'id',
		TER.[EvaluationPlanId] 'evaluationPlanId',
		TER.[total] 'total',
		TER.[completedEvaluations] 'completedEvaluations',
		TER.[completedPercentage]	'completedPercentage',	
		TE.[CreatedDate] 'createdDate', 
		CASE WHEN TER.[completedPercentage] = 100 THEN 'COMPLETED' 
			 WHEN TER.[completedPercentage] = 0 THEN 'CREATED' ELSE 'IN_PROCESS' END  'statusDescription',
		TE.[AuditorId]	'auditorId'
		
		FROM Temp_EfectivityPlan_Result TER 
		INNER JOIN (SELECT DISTINCT [EfectivityPlanId],[EvaluationPlanId],[CreatedDate],[AuditorId] FROM dbo.[EvaluationResultEfectivity]
					WHERE VCC = @VCC) AS TE ON 
		TER.EfectivityPlanId = TE.EfectivityPlanId
	    AND TER.EvaluationPlanId = TE.EvaluationPlanId
		

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.8.2_database.tar.gz: database/mssql/procedures/GetEfectivityPlans.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE  PROCEDURE [dbo].[GetEfectivityPlans] (
@VCC                Varchar(50) = NULL,
@SearchCriteria     Varchar(50) = NULL,
@SearchExpression   Varchar(50) = NULL
)
AS
BEGIN
SET NOCOUNT ON

	--SELECCIONAMOS TODOS LOS PLANES AUTOMATICOS EXISTENTES PARA GENERAR  LA MUESTRA  A PARTIR DEL PLAN DE EVALUACION

    SELECT
			e.[ID]							'id',
			e.[Modality]					'modality',
			e.[DateFin]						'dateFin',
			e.CreatedDate					'createdDate',
			e.CreatedByUserId				'createdByUserId',
			e.LastModifiedDate				'lastModifiedDate',
			e.LastModifiedByUserId			'lastModifiedByUserId',
			e.Description					'description',
			e.IdEvaluationFormat            'idEvaluationFormat',
			e.Enabled						'enabled',
			e.Status						'status',
			e.Evaluation_Mode				'evaluation_mode',
			e.processId    				    'processId',
			ef.templateId    				'templateId',
			COUNT(a.IdInteraction)			'totalEvaluations',		
			COUNT(DISTINCT CASE a.[Completed] WHEN 1 THEN a.[IdInteraction] ELSE NULL END)					'completedEvaluations',
			(
				(
					CAST(
						(
							COUNT(DISTINCT CASE a.[Completed] WHEN 1 THEN a.[IdInteraction] ELSE NULL END)
							+ 
							COUNT(DISTINCT CASE a.[Status] WHEN 0 THEN a.[IdInteraction] ELSE NULL END)
						)
					 AS NUMERIC(10,2)) 
				)
				/
				CASE COUNT(DISTINCT a.[IdInteraction]) WHEN 0 THEN 1 ELSE COUNT(DISTINCT a.[IdInteraction]) END 
			) * 100																							'completedPercentage',
			e.[Percentage]					'percentage',
			e.[StatusDescription]			'statusDescription',
			e.[BatchStatus]					'batchStatus'		
		FROM EvaluationPlan e (NOLOCK)
		LEFT JOIN AuditorEvaluationPlan a (NOLOCK) 
			ON a.[Instance] = e.[Instance]
				AND a.[IdEvaluationPlan] = e.[ID]
		INNER JOIN EvaluationFormat ef (NOLOCK)
			ON ef.[Instance] = e.[Instance]
				AND ef.[ID] = e.[IdEvaluationFormat]
        
		WHERE e.Instance = @VCC
			AND e.Evaluation_Mode IN ('A','X')
			AND e.Status = '7'			
		GROUP BY e.[ID],e.[Modality],e.[DateFin],e.CreatedDate,e.CreatedByUserId,
				 e.LastModifiedDate,e.LastModifiedByUserId,e.Description,e.IdEvaluationFormat,
				 e.Enabled, e.Status, e.Evaluation_Mode,e.processId,ef.templateId, 
				 e.Percentage, e.StatusDescription, e.[BatchStatus]	
		
		
		--SELECCIONAR PLANES DE EFECTIVIDAD GENERADOS PARA LA GRILLA DE ADMINISTRACION 

		;WITH Temp_EfectivityPlan AS (

		SELECT DISTINCT 
		[EfectivityPlanId],[EvaluationPlanId],[InteractionId],[EfectivityStatus] 
		FROM dbo.[EvaluationResultEfectivity] (NOLOCK)
		WHERE [VCC] = @VCC
		),
		Temp_EfectivityPlan_Result  AS (
		SELECT [EfectivityPlanId],[EvaluationPlanId],COUNT(InteractionId)  'total',
		COUNT(DISTINCT CASE WHEN [EfectivityStatus] = 'COMPLETED' THEN [InteractionId] ELSE NULL END)					'completedEvaluations',
		CAST(CAST(COUNT(DISTINCT CASE WHEN [EfectivityStatus] = 'COMPLETED' THEN [InteractionId] ELSE NULL END) AS DECIMAL(10,2))*100
		/
		CAST(COUNT(InteractionId) AS DECIMAL(10,2)) AS DECIMAL)															'completedPercentage'
		
        FROM Temp_EfectivityPlan EP1		

		WHERE  ISNULL(EfectivityPlanId, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
			
		
		GROUP BY  EfectivityPlanId,EvaluationPlanId
		)		

		SELECT DISTINCT 
		TER.[EfectivityPlanId] 'id',
		TER.[EvaluationPlanId] 'evaluationPlanId',
		TER.[total] 'total',
		TER.[completedEvaluations] 'completedEvaluations',
		TER.[completedPercentage]	'completedPercentage',	
		TE.[CreatedDate] 'createdDate', 
		CASE WHEN TER.[completedPercentage] = 100 THEN 'COMPLETED' 
			 WHEN TER.[completedPercentage] = 0 THEN 'CREATED' ELSE 'IN_PROCESS' END  'statusDescription',
		TE.[AuditorId]	'auditorId'
		
		FROM Temp_EfectivityPlan_Result TER 
		INNER JOIN (SELECT DISTINCT [EfectivityPlanId],[EvaluationPlanId],[CreatedDate],[AuditorId] FROM dbo.[EvaluationResultEfectivity]
					WHERE VCC = @VCC) AS TE ON 
		TER.EfectivityPlanId = TE.EfectivityPlanId
	    AND TER.EvaluationPlanId = TE.EvaluationPlanId
		

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
